@@ -1,5 +1,5 @@
 #
-# Copyright (c) 1995-2013 Jarkko Hietaniemi. All rights reserved.
+# Copyright (c) 1995-2015 Jarkko Hietaniemi. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -13,7 +13,7 @@ package BSD::Resource;
 use strict;
 use vars qw(@ISA @EXPORT @EXPORT_OK $AUTOLOAD $VERSION);
 
-$VERSION = '1.2908';
+$VERSION = '1.2909';
 
 use Carp;
 use AutoLoader;
@@ -271,6 +271,9 @@ The $resource argument can be one of
         RLIMIT_AIO_OPS          maximum number          1
                                 for POSIX AIO ops
 
+        RLIMIT_NPTS             maximum number of       1
+                                pseudo-terminals
+
         RLIMIT_SBSIZE           socket buffer size      bytes
 
         RLIMIT_SWAP             maximum swap size       bytes
@@ -517,7 +520,7 @@ at all so it stays zero.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 1995-2013 Jarkko Hietaniemi All Rights Reserved
+Copyright 1995-2015 Jarkko Hietaniemi All Rights Reserved
 
 This module free software; you can redistribute it and/or modify it
 under the terms of the Artistic License 2.0 or GNU Lesser General
